summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberchatsession.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabberchatsession.cpp')
-rw-r--r--kopete/protocols/jabber/jabberchatsession.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/protocols/jabber/jabberchatsession.cpp b/kopete/protocols/jabber/jabberchatsession.cpp
index 60c109ae..d10f4201 100644
--- a/kopete/protocols/jabber/jabberchatsession.cpp
+++ b/kopete/protocols/jabber/jabberchatsession.cpp
@@ -253,7 +253,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
jabberMessage.setSubject ( message.subject () );
jabberMessage.setTimeStamp ( message.timestamp () );
- if ( message.plainBody().tqfind ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
+ if ( message.plainBody().find ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
{
/*
* This message is encrypted, so we need to set
@@ -270,7 +270,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
// remove PGP header and footer from message
encryptedBody.truncate ( encryptedBody.length () - TQString("-----END PGP MESSAGE-----").length () - 2 );
- encryptedBody = encryptedBody.right ( encryptedBody.length () - encryptedBody.tqfind ( "\n\n" ) - 2 );
+ encryptedBody = encryptedBody.right ( encryptedBody.length () - encryptedBody.find ( "\n\n" ) - 2 );
// assign payload to message
jabberMessage.setXEncrypted ( encryptedBody );
@@ -286,16 +286,16 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
{
TQString xhtmlBody = message.escapedBody();
// According to JEP-0071 8.9 it is only RECOMMANDED to tqreplace \n with <br/>
// which mean that some implementation (gaim 2 beta) may still think that \n are linebreak.
// and considered the fact that KTextEditor generate a well indented XHTML, we need to remove all \n from it
// see Bug 121627
// Anyway, theses client that do like that are *WRONG* considreded the example of jep-71 where there are lot of
// linebreak that are not interpreted. - Olivier 2006-31-03
- xhtmlBody.tqreplace("\n","");
+ xhtmlBody.replace("\n","");
//&nbsp; is not a valid XML entity
- xhtmlBody.tqreplace("&nbsp;" , "&#160;");
+ xhtmlBody.replace("&nbsp;" , "&#160;");
// Remove trailing line break
xhtmlBody.remove( TQRegExp( "<br/>$" ) );
@@ -358,4 +358,4 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
#include "jabberchatsession.moc"
// vim: set noet ts=4 sts=4 sw=4:
-// kate: tab-width 4; tqreplace-tabs off; space-indent off;
+// kate: tab-width 4; replace-tabs off; space-indent off;
@@ -286,16 +286,16 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
{
TQString xhtmlBody = message.escapedBody();
- // According to JEP-0071 8.9 it is only RECOMMANDED to tqreplace \n with <br/>
+ // According to JEP-0071 8.9 it is only RECOMMANDED to replace \n with <br/>
// which mean that some implementation (gaim 2 beta) may still think that \n are linebreak.
// and considered the fact that KTextEditor generate a well indented XHTML, we need to remove all \n from it